"use strict";
require('rxjs/Rx');
var http_loader_1 = require('@ngx-translate/http-loader');
var locale_service_1 = require('./locale.service');
//en.temp.json must always exist.  At the very least it can be empty {}
//we only secondary translation for en language.
var TranslationLoader = (function () {
    function TranslationLoader(http, prefix, suffix) {
        this.USE_DEFAULT = true;
        this.mainTransloader = new http_loader_1.TranslateHttpLoader(http, prefix, suffix);
        this.secondaryTransloader = new http_loader_1.TranslateHttpLoader(http, prefix, '.temp' + suffix);
        console.log('EMI ==> TranslationLoader ==> Instantiated');
    }
    TranslationLoader.prototype.getTranslation = function (lang) {
        var _this = this;
        var main = this.getMainTranslation(lang);
        if (lang === 'en' || lang === 'en_us') {
            return main.flatMap(function (data) {
                return _this.mergeSecondaryTranslation(data);
            });
        }
        if (this.USE_DEFAULT) {
            return main.flatMap(function (data) {
                return _this.mergeDefaultTranslation(data);
            });
        }
        return main;
    };
    TranslationLoader.prototype.getMainTranslation = function (lang) {
        return this.mainTransloader.getTranslation(lang);
    };
    TranslationLoader.prototype.mergeSecondaryTranslation = function (main) {
        var _this = this;
        return this.secondaryTransloader.getTranslation(locale_service_1.LocaleService.DEFAULT_LOCALE).map(function (data) {
            _this.merge(main, data);
            return main;
        });
    };
    TranslationLoader.prototype.mergeDefaultTranslation = function (main) {
        var _this = this;
        return this.mainTransloader.getTranslation(locale_service_1.LocaleService.getDefaultAppLangID()).map(function (data) {
            _this.merge(data, main);
            return data;
        });
    };
    TranslationLoader.prototype.merge = function (current, update) {
        var _this = this;
        Object.keys(update).forEach(function (key) {
            if (current.hasOwnProperty(key) && typeof current[key] === 'object') {
                _this.merge(current[key], update[key]);
            }
            else {
                current[key] = update[key];
            }
        });
    };
    return TranslationLoader;
}());
exports.TranslationLoader = TranslationLoader;
